.. hckr documentation master file, created by
   sphinx-quickstart on Wed Jun 12 20:06:39 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


Kubernetes
===============


Kubernetes is a popular open-source container orchestration system. This section contains guides for several common Kubernetes commands you will use in daily development.

Introduction
------------

Kubernetes, also known as K8s, helps with deploying, scaling and managing containerized applications.

.. tip::
   More commands will be added in future updates. Stay tuned!

kubernetes commands
-------------------

.. toctree::
    context
    namespace
    pod

